/*
 * Copyright (c) 2010-2016, Sikuli.org, sikulix.com
 * Released under the MIT License.
 *
 */
package org.sikuli.script;

/**
 * INTERNAL USE
 */
public enum FindFailedResponse{
   ABORT,
   PROMPT,
   SKIP,
   RETRY,
   HANDLE
};
